package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````K!4``#0````\D0````0`!30`(``'
M`"@`%P`6``8````T````-````#0```#@````X`````4````$`````P```!0!
M```4`0``%`$``!@````8````!`````$````!````````````````````R'X`
M`,A^```%```````!``$```"XC0``N(T!`+B-`0"$`@``M!(```8```````$`
M`@```,2-``#$C0$`Q(T!`/````#P````!@````0```!1Y71D````````````
M```````````````&````$````%+E=&2XC0``N(T!`+B-`0!(`@``2`(```0`
M```!````+VQI8B]L9"UM=7-L+6%R;6AF+G-O+C$`$0```%`````(````"```
M``&````E0`2`*(`0`:"&4("``0``"R`$C3B`$D&*!`@(4````%$```!5````
M6@```%L```!A````8@```&,`````````90``````````````9@```&<```!I
M```````````````!KS3H:G^:?.K3[P[.WD<M;\7?'R[%F[:XC?$.U&34?'94
M/)0A_^0.V7%8'/JA;&#"Y3\LL@&+;^)'Q@%8[Y=YN^.2?%7#/-)GK\QFB`=P
MTT-%U>PS8MOM?ZF<F^"G`@J_VE<;H^#[20``````````````````````````
M-!`````````#``<``````,"-`0```````P`/``P``````````````!(```#G
M`0`````````````2````%```````````````$0````T"`````````````!$`
M``")`0`````````````2````&P``````````````$@```,8!````````````
M`!(````C```````````````2````*@``````````````$@```!H"````````
M`````!(```#2`0`````````````2````,P``````````````(````&(#````
M`````````"$```!+```````````````2````40``````````````$@```%@`
M`````````````!(````H`P`````````````2````&0,`````````````$@``
M`)\"`````````````!(```!?```````````````2````0`(`````````````
M$@```&8``````````````!(```#4`@`````````````2````;0``````````
M````$@```'4``````````````"````")```````````````2````O0(`````
M````````$@```)$``````````````!(```"7```````````````2````H```
M````````````(````!(#`````````````!(```"\```````````````2````
MP0``````````````$@```"L"`````````````!$```#;`@`````````````2
M````;0(`````````````$@```#@#`````````````!(```!?`@``````````
M```2````W@,`````````````$@```.8"`````````````!$```!A`P``````
M```````1````D0(`````````````$@```$X#`````````````!(```!C`P``
M```````````1````R```````````````$@```$8#`````````````!(```#1
M```````````````1````EP$`````````````$@```.,``````````````"(`
M``#R```````````````@````"`$`````````````$@````H#````````````
M`!(```!]`@`````````````2````#0$`````````````$@```!,!````````
M`````"````#(`@`````````````2````+0$`````````````$@```+<!````
M`````````!(````R`0`````````````2````K0(`````````````$@```*8!
M`````````````!(````X`0`````````````2````20$`````````````$@``
M`#L"`````````````!(```"2```````````````2````3`(`````````````
M$@```(8"`````````````!(````_`P`````````````2````3P$`````````
M````$@```#`#`````````````!(```!C`0`````````````2````-@(`````
M````````$@```/4!`````````````!(```!J`0`````````````2````<0$`
M````````````$@```&`#`````````````"$```""`0`````````````2````
MC0,``&R@`0``````$``3`%L#```\$P``<`(``!(`"0`'`@``G#\```0````2
M``H`(`0``-PQ``#4"0``$@`)`)8$``!$/P``6````!(`"0#]`P``+"L```0`
M```2``D`+P0``#00```$````$@`'`$,$``"P.P``E`,``!(`"0!^`P``/)`!
M```````0`!,`B00``#`K```D`@``$@`)`'(#```\D`$``````!``$P`.!```
M*#$``+0````2``D`+00``"PI``!<````$@`)`#4$``"H,```:````!(`"0!C
M!```5"T``"`````2``D`F`,``&R@`0``````$``3`*`#``!LH`$``````!``
M$P##`P``T!4``%P````2``D`<`0``'0M```4`0``$@`)`%D$```XD`$`!```
M`!$`$@!K`P``/)`!```````0`!(`=P,``*P5````````$@`)`,P#```0,0``
M&````!(`"0#G`P``]"D``#@!```2``D`C`,``&R@`0``````$``3`'P$``"(
M+@``(`(``!(`"0``;&EB<&5R;"YS;P!O<&5N9&ER`'-T9&5R<@!R96%L;&]C
M`&%C8V5S<P!S;G!R:6YT9@!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!L<V5E
M:P!G971P:60`<W1R8VUP`&UE;7-E=`!U;FQI;FL`;65M;6]V90!?2G9?4F5G
M:7-T97)#;&%S<V5S`'-T<FYC;7``;'-T870`8VQO<V5D:7(`7TE435]D97)E
M9VES=&5R5$U#;&]N951A8FQE`&]P96X`<W1R<W1R`')E861L:6YK`%]?<W1A
M8VM?8VAK7V=U87)D`%]?8WAA7V9I;F%L:7IE`%]?<F5G:7-T97)?9G)A;65?
M:6YF;P!E>&ET`&-L;W-E`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`<F5A
M9`!R;61I<@!?7V5R<FYO7VQO8V%T:6]N`&UK9&ER`'!T:')E861?9V5T<W!E
M8VEF:6,`;65M8W!Y`'-T<FQE;@!?7W-T86-K7V-H:U]F86EL`&=E='5I9`!0
M97)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K7VQO8VL`
M<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E
M>'0`4&5R;%]A=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G<P!?9FEN:0!03%]D
M;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?:V5Y`'!E<FQ?9G)E
M90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P
M=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E
M<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R
M<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R
M87``;&EB8RYM=7-L+6%R;6AF+G-O+C$`9G!R:6YT9@!S=')D=7``<'1H<F5A
M9%]A=&9O<FL`<F5A9&1I<@!S<')I;G1F`'-T<F-H<@!S=')T;VL`<W1R;F-P
M>0!?7VQI8F-?<W1A<G1?;6%I;@!?7U]E;G9I<F]N`%]E9&%T80!?7V)S<U]S
M=&%R=`!?7V)S<U]S=&%R=%]?`%]?8G-S7V5N9%]?`%]?96YD7U\`7V5N9``O
M=7-R+VQI8B]P97)L-2]C;W)E7W!E<FPO0T]210!?<W1A<G1?8P!G971?=7-E
M<FYA;65?9G)O;5]G971P=W5I9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R
M7V-U<G)E;G1?97AE8P!P87)?<V5T=7!?;&EB<&%T:`!P87)?;6MT;7!D:7(`
M>'-?:6YI=`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0D]/5`!M
M>5]P87)?<&P`<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A<E]I;FET7V5N
M=@!P87)?9FEN9'!R;V<`<&%R7V-L96%N=7````"XC0$`%P```+R-`0`7````
MN(\!`!<```#$CP$`%P```-2/`0`7`````)`!`!<````(D`$`%P````R0`0`7
M````%)`!`!<````8D`$`%P```!R0`0`7````()`!`!<````DD`$`%P```"R0
M`0`7````,)`!`!<````XD`$`%P```+R/`0`5!0``P(\!`!4&``#(CP$`%0X`
M`,R/`0`5&P``T(\!`!4@``#8CP$`%20``-R/`0`5*@``X(\!`!4N``#DCP$`
M%3$``.B/`0`5,P``[(\!`!4T``#PCP$`%3D``/2/`0`5/@``^(\!`!4_``#\
MCP$`%40``,".`0`6`P``Q(X!`!8$``#(C@$`%@<``,R.`0`6"```T(X!`!8)
M``#4C@$`%@H``-B.`0`6"P``W(X!`!8,``#@C@$`%@T``.2.`0`6#@``Z(X!
M`!80``#LC@$`%A$``/".`0`6$@``](X!`!83``#XC@$`%A0``/R.`0`6%0``
M`(\!`!86```$CP$`%A<```B/`0`6&```#(\!`!89```0CP$`%AH``!2/`0`6
M'```&(\!`!8=```<CP$`%AX``""/`0`6'P``)(\!`!8A```HCP$`%B(``"R/
M`0`6(P``,(\!`!8E```TCP$`%B8``#B/`0`6)P``/(\!`!8H``!`CP$`%BD`
M`$2/`0`6+```2(\!`!8M``!,CP$`%B\``%"/`0`6,```5(\!`!8R``!8CP$`
M%C,``%R/`0`6-```8(\!`!8U``!DCP$`%C8``&B/`0`6-P``;(\!`!8X``!P
MCP$`%CH``'2/`0`6.P``>(\!`!8\``!\CP$`%CT``("/`0`60```A(\!`!9!
M``"(CP$`%D(``(R/`0`60P``D(\!`!9%``"4CP$`%D8``)B/`0`61P``G(\!
M`!9(``"@CP$`%DD``*2/`0`62@``J(\!`!9+``"LCP$`%DP``+"/`0`630``
MM(\!`!9/```!0"WI`4"]Z![_+^$$X"WE!."?Y0[@C^`(\+[E9'X!``#&C^(7
MRHSB9/Z\Y0#&C^(7RHSB7/Z\Y0#&C^(7RHSB5/Z\Y0#&C^(7RHSB3/Z\Y0#&
MC^(7RHSB1/Z\Y0#&C^(7RHSB//Z\Y0#&C^(7RHSB-/Z\Y0#&C^(7RHSB+/Z\
MY0#&C^(7RHSB)/Z\Y0#&C^(7RHSB'/Z\Y0#&C^(7RHSB%/Z\Y0#&C^(7RHSB
M#/Z\Y0#&C^(7RHSB!/Z\Y0#&C^(7RHSB_/V\Y0#&C^(7RHSB]/V\Y0#&C^(7
MRHSB[/V\Y0#&C^(7RHSBY/V\Y0#&C^(7RHSBW/V\Y0#&C^(7RHSBU/V\Y0#&
MC^(7RHSBS/V\Y0#&C^(7RHSBQ/V\Y0#&C^(7RHSBO/V\Y0#&C^(7RHSBM/V\
MY0#&C^(7RHSBK/V\Y0#&C^(7RHSBI/V\Y0#&C^(7RHSBG/V\Y0#&C^(7RHSB
ME/V\Y0#&C^(7RHSBC/V\Y0#&C^(7RHSBA/V\Y0#&C^(7RHSB?/V\Y0#&C^(7
MRHSB=/V\Y0#&C^(7RHSB;/V\Y0#&C^(7RHSB9/V\Y0#&C^(7RHSB7/V\Y0#&
MC^(7RHSB5/V\Y0#&C^(7RHSB3/V\Y0#&C^(7RHSB1/V\Y0#&C^(7RHSB//V\
MY0#&C^(7RHSB-/V\Y0#&C^(7RHSB+/V\Y0#&C^(7RHSB)/V\Y0#&C^(7RHSB
M'/V\Y0#&C^(7RHSB%/V\Y0#&C^(7RHSB#/V\Y0#&C^(7RHSB!/V\Y0#&C^(7
MRHSB_/R\Y0#&C^(7RHSB]/R\Y0#&C^(7RHSB[/R\Y0#&C^(7RHSBY/R\Y0#&
MC^(7RHSBW/R\Y0#&C^(7RHSBU/R\Y0#&C^(7RHSBS/R\Y0#&C^(7RHSBQ/R\
MY0#&C^(7RHSBO/R\Y0#&C^(7RHSBM/R\Y0#&C^(7RHSBK/R\Y0#&C^(7RHSB
MI/R\Y0#&C^(7RHSBG/R\Y0#&C^(7RHSBE/R\Y0#&C^(7RHSBC/R\Y0#&C^(7
MRHSBA/R\Y0#&C^(7RHSB?/R\Y7!`+>D@T$WB(#"-X@P@(^4#(*#A'`"-Y1@0
MC>4<`(WB&!"-XOA!G^6I___K]#&?Y01`C^`#,)3G##"-Y>@QG^4,()WE`S"4
MYP(0H.$#`*#A$#"-Y5G__^O0,9_E`S"4YP!@T^7(,9_E``!6XP-0E.<+```:
M>___Z[@AG^4``%#C`B"/X.@/`N4!```:`0"@XYC__^NI___K``"5Y;___^M5
M9L#E``"5Y;S__^ON,]#E`C"#X^XSP.4``)7EM___Z^XST.4!,(/C[C/`Y1P`
MG>4%`(#B!P%PXP8``)I8,9_E6`&?Y0,PE.<``(_@`Q"@X0PPC>4?___K``&@
MX8G__^L8P)WE."&?Y0`0G.4"((_@`!"`Y2P1G^7P#P+E`1"/X`00@.4@$9_E
M`#"@X0$0C^``$)'E"!"`Y1`1G^4!$(_@#!"@Y000H./T'P+E`1"@XQP@G>4"
M`%'A+0``N@`0H.,-`8+BZ$"?Y0`1@^<`$(WEX!"?Y01`C^`#((+B`1"/X.@/
M%.4E___K`%!0X@(``!KH#Q3E7?__ZP!0H.&X0)_E!$"/X.@/%.4]___KK`"?
MY0``C^#K`P#K``!0XPP``!KL/Q3E``!3XP,``!J0`)_E``"/X.,#`.OL#P3E
MA#"?Y0,PC^#L#Q/E``!0XP````J$"@#K<#"?Y0,PC^#H#Q/E;___Z\G^_^L%
M`*#A(-"-XG"`O>@!X9SG`1"!X@3@H.7+___J0'L!`$@!``!$`0``#`$``"0!
M``",G`$`*`$``.LK````G`$`""X``,A[`0#K+0``F)L!`,@4``!LFP$`=2L`
M``HK```LFP$`%)L!``"PH.,`X*#C$!"?Y0$0C^`-`*#A#\#`XPS0H.$```#K
M!'@!`!]`+>E`,)_E0""?Y0,PC^`"()/G"""-Y30@G^4"()/G#""-Y0`@H.,$
M((WE)""?Y0(PD^<$((#B`#"-Y0`0D.4(,)WE#`"=Y?/^_^O0>`$`(`$```0!
M```0`0``2#"?Y4@`G^4#,(_@``"/X`,P@^(\()_E`#!#X`8`4^,"((_@'O\O
MD2PPG^4(T$WB`S"2YP0PC>4``%/C`0``"@C0C>(3_R_A"-"-XA[_+^$`>@$`
M_'D!`&!X`0`<`0``3`"?Y4P0G^4``(_@`1"/X``00>!!$:#A/#"?Y:$?@>#!
M$+#A`S"/X![_+P$L()_E"-!-X@(PD^<$,(WE``!3XP$```H(T(WB$_\OX0C0
MC>(>_R_AH'D!`)QY`0#\=P$`/`$``&@PG^400"WI`S"/X``PT^5<0)_E``!3
MXP1`C^`0@+T84#"?Y0,PE.<``%/C`@``"D0PG^4#`)_GN_[_Z[[__^LX,)_E
M`S"4YP``4^,"```*+`"?Y0``C^!<_O_K`2"@XR`PG^4#,(_@`"##Y1"`O>@\
M>0$`I'<!`#0!``#4>`$`%`$``'AG``#@>`$`$T`MZ5Q`G^5<,)_E!$"/X`,P
ME.<``%/C!```"DP0G^5,`)_E`1"/X```C^">_O_K0`"?Y0``C^``,)#E``!3
MXP4```HP,)_E`S"4YP0PC>4``%/C````"C/_+^$(T(WB$$"]Z*G__^HD=P$`
M.`$``)AX`0`89P``"'8!`!@!``#P3RWIR#N?Y<@KG^4#,(_@`C"3YU7?3>($
M,(WE`#"3Y1S`@.),,8WE`#"@XPP@C>(#$9SG,1^_Y@,1@N<!,(/B$`!3X_G_
M_QI`P*#C`A"@X2#@D>4T,)'E!"""X@XP(^`(X)'E`!"1Y0XP(^`!,"/@XS^@
MX0'`7.(\,(+E\O__&E0[G^4,X)WE!'"0Y0A0@.)@`97H`)"0Y0/@CN`&("7@
M!R`"X`C@CN#I[8[@!B`BX&=!H.$"X([@$""=Y03`)>`)P`S@`R""X`7`+.`&
M((+@::&@X0+`C.`4()WE"A`DX`X0`>`#((+@!2""X`00(>#NS8S@`A"!X&[A
MH.$8()WE#K`JX`RP"^`#((+@[!V!X`0@@N!LP:#A"K`KX!Q`G>4"L(O@#"`N
MX`-`A.`!(`+@"J"$X`X@(N#AO8O@"B""X&$1H.$@H)WE`4`LX`.@BN`+0`3@
MZRV"X`[@BN!KL:#A#$`DX"2@G>4.0(3@"^`AX`.@BN`"X`[@#,"*X`'@+N#B
M383@#.".X&(AH.$HP)WE`J`KX`/`C.`$H`K@`1",X`N@*N#D[8[@`:"*X&1!
MH.$L$)WE!,`BX`,0@>`.P`S@"["!X`+`+.#NK8K@"\",X&[AH.$PL)WE#A`D
MX`.PB^`*$`'@ZLV,X`(@B^!JH:#A!!`AX#2PG>4"$('@"B`NX`.PB^`,(`+@
M[!V!X`1`B^!LP:#A#B`BX#BPG>4$((+@#$`JX`.PB^`!0`3@X2V"X`[@B^!A
M$:#A"D`DX#RPG>4.0(3@`>`LX`.PB^`"X`[@"J"+X`S@+N#B383@"N".X&(A
MH.%`H)WE`K`AX`.@BN`$L`O@#,"*X`&P*^#D[8[@#+"+X&1!H.%$P)WE!*`B
MX`/`C.`.H`K@[KV+X`$0C.!NX:#A`J`JX$C`G>4!H(K@#A`DX`/`C.`+$`'@
MZZV*X`00(>!KL:#A`B",X$S`G>4"(('@"Q`NX`/`C.`*$`'@ZBV"X`X0(>!J
MH:#A!$",X%#`G>4$0('@"A`KX`/`C.`"$`'@"Q`AX`[@C.#B383@#N"!X&(A
MH.%4$)WE`L`JX`,0@>`$P`S@"["!X`K`+.#D[8[@"\",X&1!H.%8L)WE!!`B
MX`,PB^`.$`'@"J"#X`(0(>"$.)_E"A"!X%R@G>7NS8S@`Z"*X&[AH.$"((K@
M#J`DX`R@*N`*((+@8*"=Y>P=@>`#H(K@;,&@X01`BN`,H"[@`:`JX`I`A.!D
MH)WEX2V"X`.@BN!A$:#A#N"*X`&@+.`"H"K@"N".X&B@G>7B383@`Z"*X&(A
MH.$,P(K@`J`AX`2@*N`*P(S@;*"=Y>3MCN`#H(K@9$&@X0$0BN`$H"+@#J`J
MX`H0@>!PH)WE[LV,X`.@BN!NX:#A`B"*X`Z@).`,H"K@"B""X'2@G>7L'8'@
M`Z"*X&S!H.$$0(K@#*`NX`&@*N`*0(3@>*"=Y>$M@N`#H(K@81&@X0[@BN`!
MH"S@`J`JX`K@CN!\H)WEXDV$X`.@BN!B(:#A#,"*X`*@(>`$H"K@"L",X("@
MG>7D[8[@`Z"*X&1!H.$!$(K@!*`BX`Z@*N`*$('@A*"=Y>[-C.`#H(K@;N&@
MX0(@BN`.H"3@#*`JX`H@@N"(H)WE[!V!X`.@BN!LP:#A!$"*X`R@+N`!H"K@
M"D"$X(R@G>7A+8+@`Z"*X&$1H.$.X(K@`:`LX`*@*N`*X([@D*"=Y>)-A.`#
MH(K@8B&@X0S`BN`"H"'@!*`JX`K`C."4H)WEY.V.X`.@BN!D0:#AF+"=Y0$0
MBN`$H"+@[LV,X`Z@*N`#L(O@;N&@X0H0@>`"L(O@G*"=Y0X@).`,("+@[!V!
MX`*PB^!LP:#A`Z"*X*`@G>4$H(K@#$`NX.&]B^`!0"3@`R""X&$1H.$.X(+@
M`2`LX`L@(N`"X([@I""=Y02@BN#KK8K@`R""X&NQH.$,P(+@"R`AX`H@(N`"
MP(S@J""=Y>KMCN`#,(+@:J&@X0$0@^`*,"O@[LV,X`XP(^!NX:#A#B"*X0,0
M@>`,(`+@#C`*X`,@@N&L0)WEY#6?Y>P=@>`#0(3@;,&@X0NPA.`,0([A"R""
MX`%`!.`,L`[@"T"$X;"PG>7A+8+@`["+X&$1H.$*H(O@"D"$X`&@C.$!L`S@
M`J`*X`N@BN&TL)WEXDV$X`.PB^!B(:#A#N"+X`[@BN`"H('A`K`!X`2@"N`+
MH(KAN+"=Y>3MCN`#L(O@9$&@X0S`B^`,P(K@!*""X02P`N`.H`K@"Z"*X;RP
MG>7NS8S@`["+X&[AH.$!$(O@`1"*X`Z@A.$.L`3@#*`*X`N@BN'`L)WE[!V!
MX`.PB^!LP:#A`B"+X`(@BN`,H([A#+`.X`&@"N`+H(KAQ+"=Y>$M@N`#L(O@
M81&@X01`B^`$0(K@`:",X0&P#.`"H`K@"Z"*X<BPG>7B383@`["+X&(AH.$.
MX(O@#N"*X`*@@>$"L`'@!*`*X`N@BN',L)WEY.V.X`.PB^!D0:#A#,"+X`S`
MBN`$H(+A!+`"X`Z@"N`+H(KAT+"=Y>[-C.`#L(O@;N&@X0$0B^`!$(K@#J"$
MX0ZP!.`,H`K@"Z"*X=2PG>7L'8'@`["+X&S!H.$"((O@`B"*X`R@CN$,L`[@
M`:`*X`N@BN'8L)WEX2V"X`.PB^!A$:#A!$"+X`1`BN`!H(SA`;`,X`*@"N`+
MH(KAW+"=Y>)-A.`#L(O@8B&@X0[@B^`.X(K@`J"!X0*P`>`$H`K@"Z"*X>"P
MG>7D[8[@`["+X&1!H.$,P(O@#,"*X`2@@N$$L`+@#J`*X`N@BN'DL)WE[LV,
MX`.PB^!NX:#A`1"+X`$0BN`.H(3A#K`$X`R@"N`+H(KAZ+"=Y>P=@>`#L(O@
M;,&@X0(@B^`"((K@#*".X0RP#N`!H`K@"Z"*X>RPG>7A+8+@`["+X&$1H.$$
M0(O@!$"*X`&@C.$!L`S@`J`*X`N@BN'PL)WEXDV$X`.PB^!B(:#A#N"+X`[@
MBN`"H('A`K`!X`2@"N`+H(KA]+"=Y>3MCN`#L(O@9$&@X0S`B^`,P(K@!*""
MX0ZP"N`$H`+@"J"+X?BPG>7NS8S@`S"+X`$0@^`!$(K@W#*?Y>RM@>#\$)WE
M;N&@X0,0@>`"(('@#A`DX`P0(>`!((+@`!&=Y6S!H.$#$('@!$"!X`P0+N`*
M$"'@`4"$X`01G>7J+8+@`Q"!X&JAH.$.X('@"A`LX`(0(>`!X([@"!&=Y>)-
MA.`#$('@8B&@X0S`@>`"$"K@!!`AX`'`C.`,$9WEY.V.X`,0@>!D0:#A"J"!
MX`00(N`.$"'@`:"*X!`1G>7NS8S@`Q"!X&[AH.$"(('@#A`DX`P0(>`!$(+@
M%"&=Y>RMBN`#((+@;,&@X01`@N`,("[@"B`BX`)`A.`8(9WEZAV!X`,@@N!J
MH:#A#N""X`H@+.`!("+@`B".X!SAG>7A383@`^".X&$1H.$,P([@`>`JX`3@
M+N`.P(S@(.&=Y>0M@N`#X([@9$&@X0J@CN`$X"'@`N`NX`[@BN`DH9WEXLV,
MX`.@BN!B(:#A`1"*X`*@).`,H"K@[.V.X`H0@>!LH:#A*,&=Y>X=@>`#P(S@
M!$",X`K`(N`.P"S@#,"$X"Q!G>5NX:#A`T"$X`(@A.`.0"K@`4`DX.'-C.`$
M((+@84&@X3`1G>7L+8+@`Q"!X`H0@>`$H"[@#*`JX`H0@>`TH9WE;,&@X0.@
MBN`.X(K@#*`DX`*@*N#B'8'@"N".X&*AH.$X(9WEX>V.X`,@@N`$((+@"D`L
MX`%`).`$((+@/$&=Y6$1H.$#0(3@#,"$X`%`*N`.0"3@!,",X$!!G>7N+8+@
M`T"$X&[AH.$*H(3@#D`AX`)`).`$H(K@1$&=Y>+-C.`#0(3@8B&@X0$0A.`"
M0"[@#$`DX`00@>!(09WE[*V*X`,PA.`)D(/@;,&@X0[@B>`,D"+@"I`IX.H=
M@>`)X([@X>V.X`0PG>4"((C@`."`Y1`@@.5,(9WE`#"3Y0%PA^!J487@#,"&
MX`,`4N$$<(#E"%"`Y0S`@.4````*UOO_ZU7?C>+PC[WHI'8!`#`!``"9>8):
MH>O9;MR\&X_6P6+*K#"?Y?!'+>D`8%#B`S"/X`:`H`$B```*F""?Y0(PD^<`
MH)/E``!:XP9`H!$"```:"H"@X1H``.H#0*#A!#"@X0$@T^0``%+C/0!2$_G_
M_QH!D*#A"E"@X09`1.`%<*#A!("7Y```6.,-```*!""@X080H.$(`*#A.OO_
MZP``4.,)```:!##8YST`4^,&```:"E!%X$51H.$!0(3B`%")Y02`B.`(`*#A
M\(>]Z`=0H.'I___JN&H!`"P!```30"WI-#"?Y30@G^4#,(_@`D"3YPT0H.$`
M,)3E!#"-Y<?__^L$()WE`#"4Y0,`4N$````*D?O_ZPC0C>(0@+WH_&D!`#`!
M``#W0"WI`&"@X0UPH.%H0)_E:#"?Y01`C^`#4)3G`#"5Y00PC>4'$*#A!@"@
MX;+__^L``%#C!```&@0@G>4`,)7E`P!2X0H```IZ^__K,#"?Y0`@G>4#,)3G
M`#"3Y0(Q@^`$()/E``!2XP0@@^3[__\:Z___Z@S0C>+P@+WHK&D!`#`!```L
M`0``\$\MZ0%0H.'`D9_EP#&?Y0F0C^`#,)GG%-!-X@`PC>4`,)/E`&"@X0PP
MC>4`,-'E/0!3XP%0@0(%`*#A6/O_ZP@0C>(`<*#A!@"@X8C__^L`0%#B#@``
M"E'[_^L``%?A,P``B@%`1.(!,-7D``!3XP$PY.7[__\:``"@XP`PG>4,()WE
M`#"3Y0,`4N%-```*1OO_ZSPQG^4#H)GG`+":Y00QF^<``%/C#0``&B@QG^4#
M,(_@`""3Y0``4N,"((3B"0``"@(1H.$+`*#AC/K_ZP``4.,``(KE$```&@``
MX./E___J`4"$XNS__^H!$*#C`B&@X0(`H.$`$(/E!""-Y:_Z_^L`@%#B\___
M"@0@G>4+$*#A""!"XJSZ_^L`@(KE`!"@XP`PFN4!((3B`A&#YPA`C>4&,*#A
M`R"@X0$0TN0``%'C/0!1$QH``!J$()_E!C!#X`)`F><"`(?B`P"`X`B@G>4`
MD)3EE?K_ZPH!B><``%#C`#"4%0@@G14",9,7U?__"@$@UN0#$*#A``!2XST`
M4A,!(,'D"```&CT@H.,`(,/E`2#5Y```4N,!(./E^___&J___^H",*#AW?__
MZ@$PH.'N___J%-"-XO"/O>@H:0$`,`$``"P!```L:@$`\$\MZ2@QG^4H(9_E
M`S"/X`)@D^=TT$WB`#"6Y0!04.)L,(WE$P``"@`PU>4``%/C$```"C'Z_^L`
M<%#B#0``"O2`G^7TD)_E]*"?Y0B`C^`)D(_@"J"/X`<`H.%.^O_K``!0XP@`
M`!H'`*#A:_K_ZP4`H.&N^O_K;""=Y0`PEN4#`%+A*```"M#Z_^L30(#B"!"@
MX00`H.$\^O_K``!0X^S__PH)$*#A!`"@X3?Z_^L``%#CY___"@4`H.'`^O_K
M`+"@X00`H.&]^O_K``"+X`(`@.)"^O_K`+"@X00PH.$%(*#A"A"@X:GZ_^L-
M$*#A"P"@X9KZ_^L!`'#C"P"@X0<```H0,)WE#SH#X@$)4^,#```:N?__ZPL`
MH.&-^O_KS/__ZBOZ_^OZ___J=-"-XO"/O>A,9P$`,`$``"T8```H&```)Q@`
M`'!`+>E\,)_E?""?Y0,PC^`"0)/G`%"@X0``E.6'^O_K2A^`X@4`H.$G^O_K
M``!0XP$```H``*#C<("]Z```E.5^^O_K.#&0Y0\Z`^(!"5/C!0``&@(0H.,%
M`*#AY/G_ZQ`/;^&@`J#A<("]Z```E.5R^O_K.#&0Y0\Z`^(*"E/CZ___&O+_
M_^H$9@$`)`$``!-`+>D\0)_E/#"?Y01`C^`#,)3G``"3Y63Z_^LL,)_E+!"?
MY0,PE.<!$(_@!#"-Y2`PG^4$()WE`S"/X`C0C>(00+WH4_K_ZG1E`0`D`0``
M0`$``($6```\%@``$T`MZ4PPG^5,()_E`S"/X`)`D^<``)3E3?K_Z^#__^L`
M`)3E2OK_ZP`@H.,L,)_E!""-Y2@0G^4H()_E`S"/X``PC>4"((_@`1"/X+/Y
M_^L(T(WB$("]Z!AE`0`D`0``FQ@``"$6``#<$0``\$$MZ1@QG^48(9_E`S"/
MX`)PD^<"VDWB&-!-X@(JC>(`,)?E%"""X@`P@N6L^?_K]#"?Y?1@G^7T()_E
M`S"/X`R`C>(`,(WE`B"/X``PH.$&$*#A"`"@X9+Y_^L!,(#B!@!3X0```)KP
M`/#G``!0XP@``*H`,*#C`P"@X0(ZC>(4,(/B`""3Y0`PE^4#`%+A(```"B7Z
M_^L!6HWB$%"%X@$JH.,%$*#A"`"@X=3Y_^L`0%#B[O__N@$`A.*@^?_K`#!0
MXNK__PH%`%/A`@``*@0@@^`"`%7AXO__.@4`4^$"``":!""%X`(`4^'=__\Z
M!@!4X=O__\H$(*#A`P"@X040H.']^?_K`""@XP`PH.$$(,#GU___Z@+:C>(8
MT(WB\(&]Z*QD`0`P`0``XA4```$0``#*%0``L/__ZO!/+>GH<9_EZ#&?Y0=P
MC^`#@)?G`=I-XA303>(`4*#AU`&?Y0`PF.4!*HWB#"""X@``C^`!0*#A`#""
MY4S^_^LO$*#C`)"@X04`H.&.^?_K``!0XPL```J@`9_E!1"@X0``C^!V_O_K
M`3J-X@PP@^(`()/E`#"8Y04`H.$#`%+A6```"MKY_^L%`*#AU?G_ZVP1G^4`
MH*#A`1"/X`0`H.&^^?_K`$"@X5BQG^4,8(WB"["/X```5./F__\*`##4Y0``
M4^,+0*`!``!9XPD```H$$*#A"0"@X37Y_^L``%#C!```&B`1G^4!$(_@J_G_
MZP!`H.'N___J!`"@X;GY_^L`$*#C``"$X`$P4.4$($#@+P!3XQ$```H!,(KB
M`C"#X`$*4^/+__^JX#"?Y>`@G^4#,(_@`#"-Y010C>4$,*#A`B"/X`$:H.,&
M`*#A!OG_ZP$`@.(!"E#C`@``FO``\.<!$&#EY___ZJ@PG^4#0)?G``"4Y8SY
M_^M*'X#B!@"@X8#Y_^L``%#C$@``&@``E.6%^?_K.#&0Y0\Z`^(""5/C#```
M&@$0H.,&`*#AZ_C_ZP``4.,'```:7`"?Y080H.$``(_@'O[_ZP8`H.$?^?_K
M`%"@X:/__^I`$)_E``"@XP$0C^#`___J`=J-XA30C>+PC[WH<&,!`#`!``"V
M%```CQ0``&04``#M$P``%!0``,X3``"3%```)`$``"\3```<$P```#"@X0$@
MT^0``%+C````&A[_+^$O`%+C`P"@`?C__^IP0"WI`$!0X@(```H`4-3E``!5
MXP,``!KD`)_E``"/X'!`O>CX^/_J7?G_ZP$`0.(``(3@``!4X0`@H.$5```J
M`##0Y0$@0.(O`%/C#P``"@``5.$`(*#A#@``*@`PTN4!`$#B+P!3X_C__QH!
M($+B`@!4X1```#H$($+@`C""X@$*4^,2``":``"@XW"`O>@"`*#AYO__Z@``
M5.'R__\:+P!5XUP`GP4``(\`V___"E0`G^4``(_@V/__Z@`PTN4!$$+B+P!3
MX^K__QH!(*#AYO__Z@$@@N(!"E+C````FO``\.<D4)_E!!"@X050C^`$4(7B
M!0"@X>3X_^L%`*#A<("]Z#T2``"Q$0``!A(``/!A`0!P0"WIL#&?Y;`AG^4H
MT$WB`S"/X`)`D^<-4*#A#2"@X9P1G^4`,)3E`1"/X"0PC>4JP('B"C"!X@+@
MH.$``)/E!!"3Y0@P@^(#`*[H#`!3X0X@H.'W__\:L##3X60!G^6P,,[A``"/
MX'W]_^M8`9_E6&&?Y0``C^!Y_?_K4`&?Y09@C^```(_@=?W_ZT0!G^4``(_@
M<OW_ZSP!G^4``(_@;_W_ZS0!G^4``(_@;/W_ZRP!G^4``(_@:?W_ZR0!G^4`
M`(_@9OW_ZP8`H.%D_?_K%`&?Y0``C^!A_?_K#`&?Y0``C^!>_?_K!`&?Y0``
MC^!)_?_K`!!0X@$```H&`*#A>?W_Z^P`G^4``(_@0OW_ZP`04.("```*W`"?
MY0``C^!Q_?_KU`"?Y0``C^`Z_?_K`!!0X@P```K$`)_E``"/X&G]_^N\$)_E
MO`"?Y0$0C^```(_@9/W_ZR0@G>4`,)3E`P!2X1(```K+^/_KG`"?Y0``C^`H
M_?_K`!!0XI``GQ4``(\0[?__&H@0G^4*(*#C`1"/X!$`A>)*^/_K``!0X^?_
M_QIP`)_E&Q"%X@``C^#B___J*-"-XG"`O>@48`$`,`$``/`0``!$$0``/1$`
M`&\1```U$0``,A$``"T1```Q$0``VA```"41```E$0``MQ```!<1```,$0``
M"A$```D1``!2$```*!(``'D0``#1$```91```,(0```Y$```$$`MZ4PPG^4#
M,(_@`#"3Y0$`<^,,```:/`"?Y0``C^#U_/_K``!0XP0```H``-#E``!0XS``
M4!,!`*`3``"@`Q@PG^4#,(_@``"#Y1`PG^4#`)_G$("]Z$Q?`0"I#P``$%\!
M``1?`0`00"WIA?C_ZRWX_^L``%#C``"0%1"`O>CW0"WIF'"?Y0!`H.$'<(_@
M!P"@X=C\_^L`4%#B!!"@X0(```H`,-7E``!3XP0``!IP`)_E``"/X`S0C>+P
M0+WH`?W_Z@GX_^L``%#C$@``&@0`H.%E^/_K`&"@X04`H.%B^/_K``"&X`(`
M@.+G]__K`&"@X3`PG^4P$)_E`%"-Y0$0C^`#,(_@!""@X4OX_^L&$*#A!P"@
MX>;__^H,T(WB\("]Z+$/``")#P``@`X``%L/``#P3RWI-'F?Y30YG^4'<(_@
M`S"7YP+93>+\T$WB),F?Y10PC>4"*8WB`#"3Y?A`C>(,P(_@]"""X@`P@N40
M8(SBU#!$XKS@1.(`4*#A!P"<Z0<`@^@/`+;H#P"NZ`,`ENC(,$3B*,",X@,`
MCN@'`)SH!P"#Z-`(G^4``(_@D?S_ZP!@4.(/```*`##6Y0``4^,,```*K/__
MZP8`H.'`]__K`'"@X0(YC>+T,(/B`""3Y10PG>4'`*#A`#"3Y0,`4N$;`@`*
M'_C_ZYG__^L`8%#BR(!$`ET```H&`*#A%OC_ZX``H.$!`(#BF_?_ZP"@H.$`
M@*#A5)B?Y0%@1N()D(_@`2#VY0``4N-6```:O(!$X@1@F.0``%;C#```"@8`
MH.%H_/_K`&!0XOC__PH`,-;E``!3X_7__PI@_?_K``!0X_+__PH&`*#AE??_
MZP!@H.'4D$3B``!6XP4``!H$@)GD``!8XP(```H`,-CE``!3XT$``!H&`*#A
M[_?_ZP"`H.$*`*#A[/?_ZP"`B.`!BXCB!("(X@@`H.%O]__K`)"@X:PWG^6L
M%Y_E`S"/X``PC>6D-Y_E!B"@X0,PC^`!$(_@!*"-Y=#W_^L'':#C"0"@X;OW
M_^L!`'#C+P``&K7W_^L`,)#E$0!3XRL```IL-Y_E`$"5Y0,PE^<`,)/E$#"-
MY:SW_^M8%Y_E`#"0Y00@H.$`,(WE`1"/X`DPH.$0`)WEC_?_ZP!PH..=___J
M)?S_ZP`P4.(%```*`##3Y0``4^,"```*5O?_ZP!@4.*A__\:!`"8Y```4./S
M__\:!&>?Y09@C^";___J"`"@X0D0H.&E]__K`H"(XJ#__^H(`*#A#OW_ZP``
M4..S__\*"`"@X4/W_^L`8*#AK?__ZL@VG^4#H)?G``":Y93W_^M*'X#B"0"@
MX33W_^L`8%#BDP$`&@``FN6-]__K.#&0Y0\Z`^(!"5/CC0$`&@``FN6']__K
M0+&0Y9KW_^L``%OAAP$`&@``FN6!]__K.#&0Y8,[H.&C.Z#A!PU3XX`!`!H(
M`*#A$??_ZP!PH.%0!I_E``"/X.C[_^L``%#C!@``"@"`E>4;]__K`!"@X0@`
MH.&$_?_K`(!0X@```!H`@)7E"`"@X7GW_^L#`%#C`*"@X1H``-H,%I_E!`!`
MX@$0C^```(C@Y/;_ZP``4.,3```:!`!:XP,```H*H(C@!3!:Y2\`4^,-```:
M!%"5Y0``5>,*```*!0"@X63W_^L#`%#C!@``FL`5G^4$`$#B`1"/X```A>#0
M]O_K``!0XP6`H`&^_O_K`*!0XB4!`!H*$*#A"`"@X?+V_^L`L%#B(`$`"@)0
MH.,`,.#C$2#@XP!0C>4$@$3BNO;_ZP8@H.,($*#A"P"@X1_W_^L$,%3E``!3
MXRL``!H#,%3E0P!3XR@``!H",%3E00!3XR4``!H!,%3E0P!3XR(``!H`,-3E
M2`!3XQ\``!H!,-3E10!3XQP``!H`,.#C.2#@XP!0C>4+`*#AG_;_ZRD@H.,(
M$*#A"P"@X03W_^L)(*#A\#2?Y?`4G^4#,(_@!#"-Y>@TG^4`@(WE`S"/X`$0
MC^`'`*#A%_?_ZPD`H.$&]__KS`2?Y0<0H.$``(_@M/O_ZP<`H.&?_O_K]/[_
MZ@!0H.,`,*#C`%"-Y0`@H.,+`*#A@?;_ZYPTG^548(WBI#`$Y90TG^604`3E
MH#`$Y8PTG^6,4`3EG#`$Y80TG^5(4`3EF#`$Y7PTG^64,`3E7#"&XA@PC>4"
M*:#C"!"@X0L`H.'6]O_K`%!0XF4``,H+`*#AS/;_ZW\0X..04!3EB"!$XJ4Q
MH.$_,`/B`0"#XC@`4..,@!3E`Q#"Y[H``-H<L(;B0"!@X@`0H.,``(O@;/;_
MZP8`H.$D^/_K.""@XP`0H.,+`*#A9O;_ZR@\H.%0,$3E*#B@X4\P1.4H-*#A
M3C!$Y24\H.%,,$3E)3B@X4LP1.4&`*#A)32@X4V`1.5*,$3E25!$Y1#X_^ND
M,!3EN&.?Y2,LH.%$($3E(RB@X4,@1.5!,$3E(R2@X:`P%.5"($3E(RR@X4`@
M1.4C**#A/R!$Y3TP1.4C)*#AG#`4Y3X@1.4C+*#A/"!$Y2,HH.$[($3E.3!$
MY2,DH.&8,!3E.B!$Y2,LH.$X($3E(RB@X3<@1.4U,$3E(R2@X90P%.4V($3E
M(RR@X30@1.4C**#A,R!$Y2,DH.$R($3E,3!$Y42`1.(&8(_@,%!$X@H@V.>*
M`(7@!A"@X0&@BN*:]O_K%`!:X_C__QH`,*#C"#!$Y>PRG^7L$I_E`S"/X`0P
MC>7D,I_E`%"-Y0,PC^`)(*#A`1"/X'+__^J0,!3EA2&#X`(`4^&,,!2%D"`$
MY0$P@X*,,`2%C#`4Y4@@%.6E/H/@``!2XXPP!.4X```*0#!BXAP`AN(#`%7A
M`@"`X`4PH+$(`%#A`@``*@,@@.`"`%CA!```.@@`4.$#``":`R"(X`(`4.$`
M```J\`#PYP()4^/\__^*`R"@X0@0H.$0,(WE;/;_ZT@@%.40,)WE`B"#X$``
M4N-((`3E:O__&@,0B.`&`*#A$!"-Y0-01>"C]__K$!"=Y1PPAN(0,(WE/P!5
MXQ0``,H<,(;B`P!1X0(``)H%,(/@`P!1X>+__SH<,(;B`P!1X0(``"H%(('@
M`@!3X=S__SI$`%7CVO__B@4@H.$<`(;B2_;_ZTA0!.5-___J"!"@X>;__^H0
M,)WE&""=Y0,`4>$`,*"3`3"@@P(`4>$`,*`C``!3X\K__QH0,)WE`P!1X4`P
M@>("```J$""=Y0,`4N'#__\Z0""@XQ``G>4<,(WE,_;_ZP8`H.%S]__K0%!%
MXAP0G>7/___J'#"&XC@@8.(`$*#C``"#X$G__^HX$9_E.`&?Y0$0C^```(_@
MQ/K_ZYSU_^LH,9_E*!&?Y0,PC^`)`(WH(#&?Y0D@H.$#,(_@`1"/X`<`H.$6
M]O_K#$&?Y0Q1G^4,@9_E!$"/X`50C^`(@(_@!QV@XP<`H.'[]?_K`0!PX_/^
M_QKU]?_K`#"0Y1$`4^/O_O\:@O7_ZP%@AN)!`8WH!#"@X0D@H.$%$*#A!P"@
MX?_U_^OM___J2#"?Y;00G^4#`)?G`""5Y0DPH.$!$(_@``"0Y<SU_^L[_O_J
M`MF-XOS0C>+PC[WHQ%P!`#`!``#P70$`P@T``"0.``"&#0``:0T``)H,```(
M`0``'PT``+D,```D`0``^`L```8,``"["P``]PL``-@*``"V"0``?@D```$C
M16>)J\WO_MRZF'94,A#PX=+#G`@``,L)``"H"```B@<``*@'```5!@``\P<`
M`.,&``"R!0``E@4``-4&``"_!P``@@8``/=/+>D\,Y_E/".?Y0,PC^`"0)/G
M``"4Y</U_^L`4*#A``"4Y<#U_^MD,-#E'`.?Y64PQ>4``(_@+?K_ZP``4.,%
M```*`##0Y3$`4^,"```:`3#0Y0``4^,````*G?S_ZP``E.6P]?_KY!*?Y0LP
MH.,!(*#C`1"/X&#U_^L``%#C'0``&@``E.6G]?_KQ!*?Y0,PH.,!(*#C`1"/
MX%?U_^L`4%#B3P``&@``E.6>]?_KI!*?Y0,PH.,!(*#C`1"/X$[U_^L`4%#B
M8P``"HP"G^4``(_@!OK_ZP!@4.)3```*``"4Y9#U_^L&(*#A##"5Y0`0D^5'
M]?_K5P``Z@%0H.,`D*#C##"0Y52"G^48<)/E4**?Y0B`C^#T/QCE`6!%X@,`
M5>$'``"J``"4Y7[U_^L'$*#A"3"@X08@H.$%]?_K`!!0XA```!H<,I_E`S"/
MX/0O$^4!($+B`@!6X0%@H`,#4*`!QO__&O0_%>4#`%;AP___J@``E.5K]?_K
M!Q"@X<KT_^L!8(;B]O__ZO`_&.4`()'E!;&3YP@PDN4*,`/@`0M3XPP0D@4(
M```*``"4Y000C>5<]?_K!!"=Y0(PH.,`$)'E"2"@X6/U_^L`$*#A"P"@X=;T
M_^L``%#CV?__&@%0A>++___J``"4Y4[U_^L,,)7E="&?Y0`0D^4"((_@!/7_
MZPPPE>4`,)/E"#"3Y0$%$^.C__\*``"4Y4+U_^L,,)7E`!"3Y=#T_^N=___J
M`_O_ZP!@4.(``)3E*```"CGU_^L,,)7E!B"@X0`0D^7P]/_K!@"@X2?U_^L`
M`)3E,?7_ZP!0H.$``)3E+O7_Z_P0G^4!(*#C`1"/X)3T_^OP()_E`!"@X0(@
MC^`%`*#AX/3_ZP``E.4C]?_K`#"@XV4PP.70`)_ET$"?Y0``C^"/^?_K!$"/
MX```4./L#P3E#@``&O`/%.77_/_K``!0X^P/!.4)```:I`"?Y0``C^"']/_K
M$/7_ZY@PG^4#,(_@\"\3Y0PPE>4`()+E>___ZH1`G^4'':#C!$"/X.P/%.7V
M]/_K`2"`XA$`4.,!`%(3`#"@X04``)KP'Q3E7`"?Y>PO%.4`$)'E``"/X'#T
M_^L,T(WB\(^]Z/!2`0`D`0``;00``+$%``"2!0``=04``)\#``"$<P$```0@
M`$QS`0`P!```NP,``,`#``"Z`0``Y'$!`'(#``"L<0$`D'$!`#<#``!P0"WI
M`$"@X8C[_^M_^__K`%"@X5+\_^L``%#C``!4$W"`O0@`,-3E``!3XW"`O0@<
M$)_E!0"@X0$0C^"$]/_K``!5X7"`O1@$`*#A<$"]Z.[Y_^J.`0```4`MZ0%`
MO>@>_R_A<&5R;'AS:2YC`%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@
M("`@```N+@`E<R\E<P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT
M97)N86QS.CI005(Z.D)/3U0`+W!R;V,O)6DO)7,`97AE`%!!4E]414U0`%!!
M4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)0@!015),-4]05`!015),
M24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?
M1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]4
M35!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#
M3$5!3@!005)?0TQ%04X]`$Q$7TQ)0E)!4EE?4$%42`!365-414T`)3`R>``E
M<R5S)7,E<P!P87(M`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C
M=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`<&%R;``N<&%R`"5S)7-C86-H
M92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M)74M)74E<P`E<SH@<')I
M=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E
M(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*`$%21U8`&`!P97)L`#``
M4$%2.CI086-K97(Z.E9%4E-)3TX`,2XP-#$`56YA8FQE('1O(&-R96%T92!C
M86-H92!D:7)E8W1O<GD`)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@
M<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`M90`M+0!54T52
M`%5315).04U%`%1%35!$25(`5$U0`"]T;7``979A;"`G97AE8R`O=7-R+V)I
M;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@
M=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)'!A<E]T
M96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%2
M7T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ
M0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I
M;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%[4F5M
M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*1FEL93HZ1FEN9#HZ9FEN
M9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?
M=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D
M7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*
M5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE
M.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@
M/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<
M)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD
M("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R
M(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B([
M"F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["FUY("1C;60@/2`D=&UP+3YF
M:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PIC;&]S92`D=&UP.PIS
M>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E
M<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M<"T^9FEL96YA;64I.PI]
M"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE
M9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV
M*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@
M/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G
M.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y
M9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^
M("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE
M*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O
M<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(
M+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY("1B
M=68["FUY("1S:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D;V9F<V5T(#T@-3$R
M.PIM>2`D:61X(#T@+3$["G=H:6QE("@Q*0I["B1O9F9S970@/2`D<VEZ92!I
M9B`D;V9F<V5T(#X@)'-I>F4["G-E96L@7T9(+"`M)&]F9G-E="P@,B!O<B!D
M:64@<7%;<V5E:R!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A73L*;7D@)&YR
M96%D(#T@<F5A9"!?1D@L("1B=68L("1O9F9S970["F1I92!Q<5MR96%D(&9A
M:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=('5N;&5S<R`D;G)E860@/3T@)&]F
M9G-E=#L*)&ED>"`](')I;F1E>"@D8G5F+"`B7&Y005(N<&U<;B(I.PIL87-T
M(&EF("1I9'@@/CT@,"!\?"`D;V9F<V5T(#T]("1S:7IE('Q\("1O9F9S970@
M/B`Q,C@@*B`Q,#(T.PHD;V9F<V5T("H](#(["GT*;&%S="!U;FQE<W,@)&ED
M>"`^/2`P.PHD;V9F<V5T("T]("1I9'@@+2`T.PIS965K(%]&2"P@+21O9F9S
M970L(#(["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@+21O9F9S970@
M+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*<F5A9"!?1D@L("1B=68L(#0["B1D
M871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PIM>2`E<F5Q=6ER95]L:7-T.PIW
M:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E
M860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE
M(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN
M+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI
M+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D
M8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F
M+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD
M969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O
M:2D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1C<F,D97AT(BP@)&)U
M9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]
M("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65]
M(#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL
M:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N
M86UE(#T@7W1E;7!F:6QE*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D[
M"F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER
M95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[
M)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE
M(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A
M;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T
M=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D9FEL96YA;64@
M/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["FUY("1K
M97D["F9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PIN97AT('5N;&5S
M<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]("1?.R!L87-T.PI]"F1E;&5T92`D
M<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["GT@;W(@<F5T
M=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U
M;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL
M93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@
M9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D9FEL96YA;64M/GMB
M=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY
M("1F:6QE;F%M92`](%]T96UP9FEL92@B)&9I;&5N86UE+3Y[8W)C?2YP;2(L
M("1F:6QE;F%M92T^>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPG+"`D9FEL96YA
M;64@;W(@9&EE(")C86XG="!R96%D("1F:6QE;F%M93H@)"$B.PIB:6YM;V1E
M*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE
M9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E
M(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ
M2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM
M>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2![
M"G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$
M4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER
M92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I
M;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R
M97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q
M(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]
M"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A
M8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI
M=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T
M(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@
M;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*
M;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L
M;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I
M9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G
M*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@
M0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A
M9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!
M24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@
M>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2![
M"F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T
M($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@
M)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]
M"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF
M("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG
M*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T
M(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?
M;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES
M=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN
M8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH
M*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@
M0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]
M"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R
M8VAI=F4Z.EII<#L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP
M.PII9B`H9&5F:6YE9"`D<&%R*2!["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3
M:7IE*#$R."HQ,#(T*3L*;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@
M(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PIB:6YM;V1E*"1F:"D["F)L97-S
M*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*
M*"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H
M:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@(E)E860@)R1P87(G(&5R<F]R
M.B`D(2(["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A
M(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N
M*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O
M7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*;&]C86P@)"\@/2!<-#L*:68@
M*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B
M)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD["F1I92`B)'!A<B!I<R!N;W0@82!0
M05(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*?0I#<F5A
M=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*
M24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@
M24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@)"$["F)I;FUO
M9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O
M<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<B`]('-C86QA
M<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@
M/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L
M;V%D97(L("0P*0I]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I
M('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@
M)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`](")?7T5.5E]0
M05)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N('5C
M*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PHD
M;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S
M970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O(#T@=6YD968[
M"FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO
M9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L*
M*"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG
M>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI
M8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`
M1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM
M>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*;7D@)7=R
M:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1N86UE
M+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&YA;64@
M/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]("1?.PIL
M87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L*
M*"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I9B`H;2%>
M+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY("1R968@/2`D
M4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I
M(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O)#$B*2![
M"B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*
M?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[
M)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<
M+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A086-K:6YG("(I
M+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q*"(N+BXI
M"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]
M("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L("1F:6QE
M(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E*$9)3$4I
M.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"FEF("$D
M14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L
M*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<
M)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET=&5N(&%S
M("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R:6YT*'!A
M8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT*'-P<FEN
M=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O
M;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H
M*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]"B1Z:7`M
M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@
M/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE
M(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`]
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W
M*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z
M.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$
M:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D
M1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S:6]N
M(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C='@M
M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D
M8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*8FEN;6]D92@D9F@I
M.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD8V%C:&5?
M;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64["GT*)&-A
M8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D[
M"B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA
M;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H
M)&QO861E<BDI*3L*)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PHD9F@M/F-L
M;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@
M9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@
M4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER
M92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["FUY("1F:"`]($E/.CI&:6QE+3YN97<[
M"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`
M(CL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]
M/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PIP=7-H
M($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA
M;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T<RAQ
M<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["FEF("AD
M969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T
M:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S
M("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R
M7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E
M<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E
M<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>
M+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA
M;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT
M<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M
M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP<&EN9R`B
M)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E
M<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M
M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE>'1R86-T
M5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T7VYA
M;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,
M:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6
M.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L
M92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;
M+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R
M;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@
M>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY
M("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF
M:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H
M.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[
M(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L
M97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E
M(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR
M97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V
M>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E
M<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ
M5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR
M97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/
M.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI
M=F4Z.EII<#L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q
M=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@
M871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U
M:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE
M=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![
M(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E
M<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@
M>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD
M969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O
M*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY
M("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2
M(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI
M('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD
M("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P
M=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E
M9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN
M,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S
M97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U53
M15).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M
M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D
M96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T
M;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I
M;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L("(\
M(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L
M(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F
M:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<
M,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D
M8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T
M.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![
M(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@
M)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]
M('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R
M<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B
M(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D
M9F@L("(\)'!R;V=N86UE(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F
M:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD<W1M<&1I<B`N/2`B)$-O;F9I
M9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z
M("1M=&EM92`I.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,
M14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D
M(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I
M<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]4
M14U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M
M<&9I;&4@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY
M("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F
M=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;W!E
M;B!M>2`D9F@L("<^)RP@)'1E;7!N86UE(&]R(&1I92`B8V%N)W0@=W)I=&4@
M)'1E;7!N86UE.B`D(2(["F)I;FUO9&4@)&9H.PIP<FEN="`D9F@@)&-O;G1E
M;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F
M:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U
M;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?
M<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345]
M(&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M
M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0
M?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@
M>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N
M86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]0
M4D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI
M(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR
M971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?
M97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*
M?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E
M<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?
M5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<
M421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II
M9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X
M97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@
M?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@
M)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D
M.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z
M.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P
M=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM
M?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345]
M(#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6
M>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92![
M"B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%
M1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'5E\P
M("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U0
M1$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D
M14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/
M0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.
M7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L
M971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!
M4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L
M96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]
M("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@
M;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@
M)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B
M(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D
M969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E
M>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R
M8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E
M(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP
M;W)T*$!P87)?87)G<RD["F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R
M;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O
M<GE<;BD*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%
M.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID
M:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%
M.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K
M*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$
M7U\*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'P7``#P%@````````$````!`````0```/4"```/````I0,`
M``P````T$```#0```)P_```9````N(T!`!L````$````&@```+R-`0`<````
M!````/7^_V\L`0``!0```*@(```&````"`(```H```"B!```"P```!`````5
M``````````,```"TC@$``@```/`!```4````$0```!<```!$#@``$0```$P-
M```2````^````!,````(````&`````````#[__]O`0``"/K__V\0````````
M`````````````````````````````````````````````````,2-`0``````
M`````$`0``!`$```0!```$`0``!`$```0!```$`0``!`$```0!```$`0``!`
M$```0!```$`0``!`$```0!```$`0``!`$```0!```$`0``!`$```0!```$`0
M``!`$```0!```$`0``!`$```0!```$`0``!`$```0!```$`0``!`$```0!``
M`$`0``!`$```0!```$`0``!`$```0!```$`0``!`$```0!```$`0``!`$```
M0!```$`0``!`$```0!```$`0``!`$```0!```$`0``!`$```0!```$`0``!`
M$```0!```$`0``!`$```0!```$`0``!`$```/!,`````````````G#\`````
M`````````````#00````````````````````````````````````````````
M`````````````)`!`/____^(0@``U3\```````"V0```KT```'Q"``#,0```
MA$(```````!N0@``<T(```````"-0@``1T-#.B`H06QP:6YE(#8N-"XP*2`V
M+C0N,`!!,@```&%E86)I``$H````!39:2P`&!P@!"0$*`A($$P$4`14!%P,8
M`1H"'`$>!"(!1`$`+G-H<W1R=&%B`"YI;G1E<G``+F=N=2YH87-H`"YD>6YS
M>6T`+F1Y;G-T<@`N<F5L+F1Y;@`N<F5L+G!L=``N:6YI=``N=&5X=``N9FEN
M:0`N<F]D871A`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N
M:F-R`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=``N05)-+F%T
M=')I8G5T97,`````````````````````````````````````````````````
M```````+`````0````(````4`0``%`$``!@```````````````$`````````
M$P```/;__V\"````+`$``"P!``#<`````P`````````$````!````!T````+
M`````@````@"```(`@``H`8```0````#````!````!`````E`````P````(`
M``"H"```J`@``*($``````````````$`````````+0````D````"````3`T`
M`$P-``#X`````P`````````$````"````#8````)````0@```$0.``!$#@``
M\`$```,````1````!`````@````_`````0````8````T$```-!````P`````
M``````````0`````````.@````$````&````0!```$`0``#\`@``````````
M```$````!````$4````!````!@```#P3```\$P``8"P`````````````!```
M``````!+`````0````8```"</P``G#\```P```````````````0`````````
M40````$````"````J#\``*@_```9/P`````````````!`````````%D````!
M`````@```,1^``#$?@``!```````````````!`````````!C````#@````,`
M``"XC0$`N(T```0```````````````0````$````;P````\````#````O(T!
M`+R-```$```````````````$````!````'L````!`````P```,"-`0#`C0``
M!```````````````!`````````"`````!@````,```#$C0$`Q(T``/`````$
M``````````0````(````B0````$````#````M(X!`+2.``!,`0``````````
M```$````!````(X````!`````P````"0`0``D```/```````````````!```
M``````"4````"`````,````\D`$`/)```#`0``````````````0`````````
MF0````$````P`````````#R0```:```````````````!`````0```*(````#
M``!P``````````!6D```,P```````````````0`````````!`````P``````
>````````B9```+(```````````````$`````````
